@@ -3,7 +3,7 @@ use Benchmark;
 my @list;
 
 package MyBenchTestFastBasic;
-use Class::Std::Fast constructor => 'basic';
+use Class::Std::Fast constructor => 'basic', isa_unsorted => 1;
 
 my %one_of :ATTR(:name<one> :default<()>);
 my %two_of :ATTR(:name<two> :default<()>);
@@ -38,7 +38,7 @@ Class::Std::initialize;
 1;
 
 package MyBenchTestFastCache;
-use Class::Std::Fast constructor => 'basic', cache => 1;
+use Class::Std::Fast constructor => 'basic', cache => 1 , isa_unsorted => 1;
 
 my %one_of :ATTR(:name<one>);
 my %two_of :ATTR(:name<two>);
@@ -52,7 +52,8 @@ package main;
 print "Info:
 Each test creates an object an stacks two objects into it (two levels)\n";
 
-for my $class ('MyBenchTestFastCache', 'MyBenchTestFastBasic') { #}, 'MyBenchTestFast', 'MyBenchTest') {
+for my $class ('MyBenchTestFastCache', 'MyBenchTestFastBasic') {
+    #, 'MyBenchTestFast', 'MyBenchTest') {
     my $n = 100000;
     print "\n$class ($n iterations - first run)\n";
     timethis $n, sub {
